Crate acktor_derive

Crate acktor_derive 

Attribute Macros

remoteipc
Attribute macro applies to the impl Actor for MyActor block, which overrides the internal method Actor::remote_mailbox to return a RemoteMailbox for a remote addressable actor.

Derive Macros

Decodeipc
Derive the Decode trait for a message.
Encodeipc
Derive the Encode trait for a message.
Message
Derive the Message trait for a struct or enum.
MessageId
Derive the MessageId trait for a Message.
MessageResponse
Derive the MessageResponse trait for a struct or enum.
RemoteAddressableipc
Derive the RemoteAddressable trait for an actor.
StableId
Derive the StableId trait for a type.