Crate acktor_derive

Crate acktor_derive 

Attribute Macros

remote_actoripc
Attribute macro applies to the impl Actor for MyActor { ... } block, which overrides the Actor::type_erased_recipient_fn used by acktor-ipc with a custom implementation that converts Address<Self> to Recipient<RemoteMessage> first and then erases the type.

Derive Macros

Decodeipc
Derive the Decode trait for a message.
Encodeipc
Derive the Encode trait for a message.
HasStableTypeId
Derive the HasStableTypeId trait for a type.
Message
Derive the Message trait for a struct or enum.
MessageId
Derive the MessageId trait for a Message.
MessageResponse
Derive the MessageResponse trait for a struct or enum.
RemoteActoripc
Derive the RemoteActor trait for an actor.