Crate acktor_derive

Crate acktor_derive 

Attribute Macros

remote
Attribute macro applies to the impl Actor for MyActor { ... } block, which overrides the Actor::type_erased_recipient_fn used by acktor-ipc with a custom implementation that converts Address<Self> to Recipient<RemoteMessage> first and then erases the type.

Derive Macros

Decode
Derive the Decode trait for a message.
Encode
Derive the Encode trait for a message.
Message
Derive the Message trait for a struct or enum.
MessageResponse
Derive the MessageResponse trait for a struct or enum.
RemoteActor
Derive the RemoteActor trait for an actor.